@@ -33,8 +33,8 @@ from PIL import Image, ImageFilter
         )
 def blur(inputimage, outputimage, radius):
     inputimage = Image.open(inputimage)
-    outputimage = inputimage.filter(ImageFilter.GaussianBlur(radius))
-    outputimage.save(outputimage, format="png")
+    bluredimage = inputimage.filter(ImageFilter.GaussianBlur(radius))
+    bluredimage.save(outputimage, format="png")
 
     click.echo(f'{inputimage} is blured to radius {radius} as {outputimage}.')
 
