@@ -5,6 +5,7 @@ import click
 #from .info import info
 from .removebg import removebg
 from .pixelate import pixelate
+from .blur import blur
 
 CONTEXT_SETTINGS = dict(
         help_option_names = [
@@ -17,7 +18,7 @@ CONTEXT_SETTINGS = dict(
 def main():
     pass
 
-
+main.add_command(blur)
 main.add_command(pixelate)
 main.add_command(removebg)
 #main.add_command(resize)
